@@ -1,6 +1,6 @@
 package File::RandomGenerator;
 {
-  $File::RandomGenerator::VERSION = '0.04';
+  $File::RandomGenerator::VERSION = '0.05';
 }
 
 # ABSTRACT: Utility to generate a random dir tree with random files.
@@ -16,23 +16,30 @@ use Smart::Args;
 use Data::Dumper;
 use Cwd;
 
+use constant DEPTH => 1;
+use constant WIDTH => 1;
+use constant FILE_CNT => 10;
+use constant ROOT_DIR => '/tmp';
+use constant UNLINK => 0;
+
+
 
 has 'depth' => ( is      => 'rw',
 				 isa     => 'Int',
-				 default => 1
+				 default => DEPTH
 );
 
 
 has 'num_files' => ( is      => 'rw',
 					 isa     => 'Int',
-					 default => 10
+					 default => FILE_CNT
 );
 
 
 
 has 'root_dir' => ( is      => 'rw',
 					isa     => 'Str',
-					default => '/tmp',
+					default => ROOT_DIR,
 );
 
 has '_template' => ( is      => 'rw',
@@ -43,13 +50,13 @@ has '_template' => ( is      => 'rw',
 
 has 'unlink' => ( is      => 'rw',
 				  isa     => 'Bool',
-				  default => 1
+				  default => UNLINK
 );
 
 
 has 'width' => ( is      => 'rw',
 				 isa     => 'Int',
-				 default => 2
+				 default => WIDTH
 );
 
 
@@ -81,7 +88,7 @@ sub generate {
 	push @$list, $file_tmp;
 	$self->_file_temp_list($list);
 
-	$self->_gen_level( file_tmp   => $file_tmp,
+	my $cnt = $self->_gen_level( file_tmp   => $file_tmp,
 					   curr_depth => 1,
 					   want_num   => $self->num_files,
 					   want_width => $self->width,
@@ -90,7 +97,7 @@ sub generate {
 
 	chdir $orig_dir or confess "failed to chdir back to $orig_dir: $!";
 	
-	return 1;
+	return $cnt;
 }
 
 sub _gen_level {
@@ -102,6 +109,8 @@ sub _gen_level {
 		my $want_width => 'Int',
 		my $curr_dir   => 'Str';
 
+	my $cnt = 0;
+	
 	for ( my $i = 0; $i < $want_num; $i++ ) {
 
 		my ( $fh, $filename )
@@ -110,6 +119,7 @@ sub _gen_level {
 								   UNLINK => 0
 			);
 		close $fh;
+		$cnt++;
 	}
 
 	if ( $curr_depth < $self->depth ) {
@@ -119,7 +129,7 @@ sub _gen_level {
 			my $dir = $file_tmp->newdir( DIR => $curr_dir, CLEANUP => 0 );
 			chdir $dir or confess "failed to chdir $dir: $!";
 			
-			$self->_gen_level( file_tmp   => $file_tmp,
+			$cnt+= $self->_gen_level( file_tmp   => $file_tmp,
 							   curr_depth => $curr_depth + 1,
 							   want_num   => $want_num * 2,
 							   want_width => $want_width * 2,
@@ -129,6 +139,8 @@ sub _gen_level {
 			chdir '..' or confess "failed to chdir: $!";
 		}
 	}
+	
+	return $cnt;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -147,7 +159,7 @@ File::RandomGenerator - Utility to generate a random dir tree with random files.
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -155,8 +167,11 @@ version 0.04
   $frg->generate;
 
   my $frg = File::RandomGenerator->new( 
-	  depth => 2,
-	  num_files = 2 
+	  depth     => 2,
+	  width     => 3,
+	  num_files => 2,
+	  root_dir  => '/tmp',
+	  unlink    => 1,
   );
   $frg->generate;
 
